@@ -16,6 +16,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# The CTAS hack is used for platforms where INSERT statements are extremely slow, and we
+# are inserting into a new table. Rather than creating the table and then inserting the data, we 
+# create the table using a CTAS statement. Because there are limits to the number of rows that 
+# can be added in a single CTAS statement, we use recursive CTAS statements, each no larger than
+# some number specified per platform.
 
 mergeTempTables <- function(connection, tableName, sqlFieldNames, sourceNames, distribution, tempTable, tempEmulationSchema) {
   unionString <- paste("\nUNION ALL\nSELECT ", sqlFieldNames, " FROM ", sep = "")
@@ -31,8 +36,8 @@ mergeTempTables <- function(connection, tableName, sqlFieldNames, sourceNames, d
     ";",
     sep = ""
   )
-  sql <- SqlRender::translate(sql, targetDialect = connection@dbms, tempEmulationSchema = tempEmulationSchema)
-  if (tempTable && connection@dbms == "redshift") {
+  sql <- SqlRender::translate(sql, targetDialect = dbms(connection), tempEmulationSchema = tempEmulationSchema)
+  if (tempTable && dbms(connection) == "redshift") {
     sql <- gsub("CREATE TABLE", "CREATE TEMP TABLE", sql)
   }
   executeSql(connection, sql, progressBar = FALSE, reportOverallTime = FALSE)
@@ -40,7 +45,7 @@ mergeTempTables <- function(connection, tableName, sqlFieldNames, sourceNames, d
   # Drop source tables:
   for (sourceName in sourceNames) {
     sql <- paste("DROP TABLE", sourceName)
-    sql <- SqlRender::translate(sql, targetDialect = connection@dbms, tempEmulationSchema = tempEmulationSchema)
+    sql <- SqlRender::translate(sql, targetDialect = dbms(connection), tempEmulationSchema = tempEmulationSchema)
     executeSql(connection, sql, progressBar = FALSE, reportOverallTime = FALSE)
   }
 }
@@ -78,7 +83,7 @@ formatRow <- function(data, aliases = c(), castValues, sqlDataTypes) {
 }
 
 ctasHack <- function(connection, sqlTableName, tempTable, sqlFieldNames, sqlDataTypes, data, progressBar, tempEmulationSchema) {
-  if (connection@dbms == "hive") {
+  if (dbms(connection) == "hive") {
     batchSize <- 750
   } else {
     batchSize <- 1000
@@ -127,7 +132,7 @@ ctasHack <- function(connection, sqlTableName, tempTable, sqlFieldNames, sqlData
         MARGIN = 1,
         FUN = formatRow,
         aliases = varAliases,
-        castValues = attr(connection, "dbms") %in% c("bigquery", "hive"),
+        castValues = dbms(connection) %in% c("bigquery", "hive"),
         sqlDataTypes = sqlDataTypes
       )),
       collapse = "\nUNION ALL\nSELECT "
@@ -147,7 +152,7 @@ ctasHack <- function(connection, sqlTableName, tempTable, sqlFieldNames, sqlData
       " FROM data;",
       sep = ""
     )
-    sql <- SqlRender::translate(sql, targetDialect = connection@dbms, tempEmulationSchema = tempEmulationSchema)
+    sql <- SqlRender::translate(sql, targetDialect = dbms(connection), tempEmulationSchema = tempEmulationSchema)
     executeSql(connection, sql, progressBar = FALSE, reportOverallTime = FALSE)
   }
   if (progressBar) {
