@@ -112,10 +112,11 @@ public class BatchedQuery {
 			String className = metaData.getColumnClassName(columnIndex + 1);
 			int precision = metaData.getPrecision(columnIndex + 1);
 			int scale = metaData.getScale(columnIndex + 1);
-			if (type == Types.INTEGER || type == Types.SMALLINT || type == Types.TINYINT
-					|| (dbms.equals("oracle") && className.equals("java.math.BigDecimal") && precision != 19 && scale == 0))
+			if (type == Types.INTEGER || type == Types.SMALLINT || type == Types.TINYINT 
+					|| (dbms.equals("oracle") && className.equals("java.math.BigDecimal") && precision > 0 && precision != 19 && scale == 0))
 				columnTypes[columnIndex] = INTEGER;
-			else if (type == Types.BIGINT || (dbms.equals("oracle") && className.equals("java.math.BigDecimal") && precision == 19 && scale == 0))
+			else if (type == Types.BIGINT
+					|| (dbms.equals("oracle") && className.equals("java.math.BigDecimal") && precision > 0 && scale == 0))
 				columnTypes[columnIndex] = INTEGER64;
 			else if (type == Types.DECIMAL || type == Types.DOUBLE || type == Types.FLOAT || type == Types.NUMERIC || type == Types.REAL)
 				columnTypes[columnIndex] = NUMERIC;
